@@ -34,9 +34,7 @@ def get_os_env(env_type='LC', env_path=None, env_file=None):
 
 
 def is_in_ipython():
-    if 'ipykernel' in sys.modules:
-        return True
-    return False
+    return 'ipykernel_launcher.py' in sys.argv[0]
     
     
 def __list_jupyterlab_workspace(target_path):
